==> cirrax-roundcube-1.0.1.tar.gz: cirrax-roundcube-1.0.1/README.md <==
# roundcube puppet module

[![Build Status](https://travis-ci.org/cirrax/puppet-roundcube.svg?branch=master)](https://travis-ci.org/cirrax/puppet-rouncube)
[![Puppet Forge](https://img.shields.io/puppetforge/v/cirrax/roundcube.svg?style=flat-square)](https://forge.puppetlabs.com/cirrax/roundcube)
[![Puppet Forge](https://img.shields.io/puppetforge/dt/cirrax/roundcube.svg?style=flat-square)](https://forge.puppet.com/cirrax/roundcube)
[![Puppet Forge](https://img.shields.io/puppetforge/e/cirrax/roundcube.svg?style=flat-square)](https://forge.puppet.com/cirrax/roundcube)
[![Puppet Forge](https://img.shields.io/puppetforge/f/cirrax/roundcube.svg?style=flat-square)](https://forge.puppet.com/cirrax/roundcube)

#### Table of Contents

1. [Overview](#overview)
1. [Usage - Configuration options and additional functionality](#usage)


## Overview

This module is used to configure roundcube webmail.

It assumes, you are using hiera to configure.

## Usage

Just include the roundcube class and add some hiera definitions....

Details about the configuration possibilities are documented in the classes.

## Contributing

Please report bugs and feature request using GitHub issue tracker.

For pull requests, it is very much appreciated to check your Puppet manifest with puppet-lint
and the available spec tests  in order to follow the recommended Puppet style guidelines
from the Puppet Labs style guide.

### Authors

This module is mainly written by [Cirrax GmbH](https://cirrax.com).

See the [list of contributors](https://github.com/cirrax/puppet-roundcube/graphs/contributors)
for a list of all contributors.

==> cirrax-roundcube-1.0.3.tar.gz: cirrax-roundcube-1.0.3/README.md <==
# roundcube puppet module

[![Build Status](https://travis-ci.org/cirrax/puppet-roundcube.svg?branch=master)](https://travis-ci.org/cirrax/puppet-rouncube)
[![Puppet Forge](https://img.shields.io/puppetforge/v/cirrax/roundcube.svg?style=flat-square)](https://forge.puppetlabs.com/cirrax/roundcube)
[![Puppet Forge](https://img.shields.io/puppetforge/dt/cirrax/roundcube.svg?style=flat-square)](https://forge.puppet.com/cirrax/roundcube)
[![Puppet Forge](https://img.shields.io/puppetforge/e/cirrax/roundcube.svg?style=flat-square)](https://forge.puppet.com/cirrax/roundcube)
[![Puppet Forge](https://img.shields.io/puppetforge/f/cirrax/roundcube.svg?style=flat-square)](https://forge.puppet.com/cirrax/roundcube)

#### Table of Contents

1. [Overview](#overview)
1. [Usage - Configuration options and additional functionality](#usage)


## Overview

This module is used to configure roundcube webmail.

It assumes, you are using hiera to configure.

## Usage

Just include the roundcube class and add some hiera definitions....

Details about the configuration possibilities are documented in the classes or look at the REFERENCE.md file.

## Contributing

Please report bugs and feature request using GitHub issue tracker.

For pull requests, it is very much appreciated to check your Puppet manifest with puppet-lint
and the available spec tests  in order to follow the recommended Puppet style guidelines
from the Puppet Labs style guide.

### Authors

This module is mainly written by [Cirrax GmbH](https://cirrax.com).

See the [list of contributors](https://github.com/cirrax/puppet-roundcube/graphs/contributors)
for a list of all contributors.
